Index: trunk/psModules/src/config/pmConfigCamera.h
===================================================================
--- trunk/psModules/src/config/pmConfigCamera.h	(revision 13704)
+++ trunk/psModules/src/config/pmConfigCamera.h	(revision 14475)
@@ -5,6 +5,6 @@
  *  @author Eugene Magnier, IfA
  *
- *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2007-06-08 00:31:50 $
+ *  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2007-08-14 00:17:40 $
  *  Copyright 2005-2006 Institute for Astronomy, University of Hawaii
  */
@@ -19,10 +19,11 @@
 bool pmConfigGenerateSkycellVersion(psMetadata *oldCameras, // Old list of camera configurations
                                     psMetadata *newCameras, // New list of camera configurations
-                                    const char *name // Name of original camera configuration
+                                    const char *name, // Name of original camera configuration
+                                    const psMetadata *site // The site configuration
     );
 
 /// Generate the skycell version of a particular camera configuration
 bool pmConfigCameraSkycellVersion(psMetadata *site, // The site configuration
-                           const char *name // Name of the un-mosaicked camera
+                                  const char *name // Name of the un-mosaicked camera
     );
 
